/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * DirectionJudge.hpp
 *
 *  Created on: 2011/01/14
 *      Author: HARK Development Team
 */

#ifndef DIRECTIONJUDGE_HPP_
#define DIRECTIONJUDGE_HPP_

#include <vector>
#include <utility>
#include <boost/shared_ptr.hpp>
//#include <AngleAndProbability.hpp>
#include <Probability.hpp>
#include <BandAndHarmonicRatio.hpp>
#include <InterauralDifference.hpp>
#include <MethodFlag.hpp>

namespace NSHarkBinaural
{

/**
 * 方向を推定するクラスの基底クラス.
 */
class DirectionJudge
{
public:
    /*
    typedef std::vector<AngleAndProbability> AngleProbabilityVector;
    typedef boost::shared_ptr<AngleProbabilityVector> AngleProbabilityVectorPtr;
    */
    typedef std::vector<std::pair<size_t, Probability> > DirectionProbabilityVector;
    typedef boost::shared_ptr<DirectionProbabilityVector> DirectionProbabilityVectorPtr;
    typedef std::vector<BandAndHarmonicRatio> BandHarmonicVector;
    typedef boost::shared_ptr<BandHarmonicVector> BandHarmonicVectorPtr;

    virtual ~DirectionJudge()
    { }

    /**
     * 方向を推定する.
     */
    virtual DirectionProbabilityVectorPtr
    Judge(const std::pair<BandHarmonicVectorPtr, BandHarmonicVectorPtr>& dividedBands,
          IPD::ptr_t ipd, IID::ptr_t iid, MethodFlag::Kind mflag, bool sortByProbability) = 0;
};

}

#endif /* DIRECTIONJUDGE_HPP_ */
